@@ -1,7 +1,7 @@
 # =====================================
 # generator=datazen
 # version=3.1.2
-# hash=fd5cef0b65ab393b390edc69e1c670f7
+# hash=9e87f6454df00f68a60186c6e98c7f81
 # =====================================
 
 """
@@ -16,6 +16,7 @@ from typing import Tuple as _Tuple
 from vcorelib.args import CommandRegister as _CommandRegister
 
 # internal
+from runtimepy.commands.arbiter import add_arbiter_cmd
 from runtimepy.commands.tui import add_tui_cmd
 
 
@@ -23,6 +24,11 @@ def commands() -> _List[_Tuple[str, str, _CommandRegister]]:
     """Get this package's commands."""
 
     return [
+        (
+            "arbiter",
+            "run a connection-arbiter application from a config",
+            add_arbiter_cmd,
+        ),
         (
             "tui",
             "run a terminal interface for the channel environment",
